@@ -79,7 +79,7 @@ class DisunityServer(quart.Quart):
             context = DisunityCommandContext(self, rjson)
             command: identifiers.DisunityCommand = self._cache.commands[str(context.type)].get(context.command_name, None)
             if command is None:
-                return jsonify({"type": 4, "data": {"content": "This command was not found within the bot", "flags": 64}})
+                raise errors.CommandNotFound(f"Command: {context.command_name} was not found")
             
             if command.requires_ack:
                 resp = {"type": 5}
@@ -99,7 +99,7 @@ class DisunityServer(quart.Quart):
             component: identifiers.DisunityComponent = self._cache.components.get(str(context.custom_id).split('-')[0], None)
 
             if component is None:
-                return jsonify({"type": 4, "data": {"content": "This component does not exist", "flags": 64}})
+                raise errors.ComponentNotFound(f"Component: {str(context.custom_id).splut('-')[0]} was not found")
 
             if component.requires_ack:
                 resp = {"type": 6}
